﻿using System;
using System.Runtime.InteropServices;

namespace WpfAudioPlayer.Models.Wmf
{
	/// <summary>
	/// The WM_MEDIA_TYPE structure is the primary structure used to describe media formats for the objects of the Windows Media Format SDK.
	/// For more information about media formats and what they are used for, see Formats.
	/// </summary>
	[StructLayout( LayoutKind.Sequential )]
	struct WM_MEDIA_TYPE
	{
		/// <summary>
		/// Major type of the media sample.
		/// For example, WMMEDIATYPE_Video specifies a video stream. For a list of possible major media types, see Media Types.
		/// </summary>
		public Guid MajorType;

		/// <summary>
		/// Subtype of the media sample. The subtype defines a specific format (usually an encoding scheme) within a major media type.
		/// For example, WMMEDIASUBTYPE_WMV3 specifies a video stream encoded with the Windows Media Video 9 codec.
		/// Subtypes can be uncompressed or compressed.
		/// For lists of possible media subtypes, see Uncompressed Media Subtypes and Compressed Media Subtypes.
		/// </summary>
		public Guid SubType;

		/// <summary>
		/// Set to true if the samples are of a fixed size.
		/// Compressed audio samples are of a fixed size while video samples are not.
		/// </summary>
		[MarshalAs( UnmanagedType.Bool )]
		public bool FixedSizeSamples;

		/// <summary>
		/// Set to true if the samples are temporally compressed.
		/// Temporal compression is compression where some samples describe the changes in content from the previous sample, instead of describing the sample in its entirety.
		/// Only compressed video can be temporally compressed. By definition, no media type can use both fixed sized samples and temporal compression.
		/// </summary>
		[MarshalAs( UnmanagedType.Bool )]
		public bool TemporalCompression;

		/// <summary>
		/// Long integer containing the size of the sample, in bytes.
		/// This member is used only if bFixedSizeSamples is true.
		/// </summary>
		public uint SampleSize;

		/// <summary>
		/// GUID of the format type.
		/// The format type specifies the additional structure used to identify the media format.
		/// This structure is pointed to by pbFormat.
		/// </summary>
		public Guid FormatType;

		/// <summary>
		/// Not used. Should be NULL.
		/// </summary>
		public IntPtr Unknown;

		/// <summary>
		/// Size, in bytes, of the structure pointed to by pbFormat.
		/// </summary>
		public uint FormatSize;

		/// <summary>
		/// Pointer to the format structure of the media type. The structure referenced is determined by the format type GUID.
		/// </summary>
		public IntPtr Format;
	}
}
